Module query

Module query 

Query builder implementation for filtering, selecting, ordering, grouping, and aggregating data.

This module provides the Query struct which enables SQL-like operations on collections using type-safe key-paths.

Structs

Query
A query builder for filtering, selecting, ordering, grouping, and aggregating data.
QueryWithSkip
Helper struct for pagination after a skip operation.